==> remotable-plugins-plugin-0.9.3.jar: js/iframe-min/host/main-min.js <==
_AP.define("host/main",["_xdm-rpc"],function(e){var f=AJS.$,g=["status","statusText","responseText"],a=["Content-Type"],c=(AJS.EventQueue=AJS.EventQueue||[]),h=window.requestAnimationFrame||function(i){setTimeout(i,10)
};
function d(i){return f("#embedded-"+i)
}function b(n){var G=n.ns,i="ap-"+G,j=f("#"+i),o=d(G),D=o.attr("id"),l="channel-"+G,v=n.w||"100%",F=n.h||"0",p=new Date().getTime(),s=!!n.dlg,r;
function C(H,I){I=f.extend(I||{},{moduleKey:G});
c.push({name:H,properties:I})
}function y(H){j.find(".ap-status").addClass("hidden");
j.find(".ap-"+H).removeClass("hidden")
}var x=setTimeout(function(){x=null;
y("load-timeout");
var H=j.find(".ap-load-timeout");
H.find("a.ap-btn-cancel").click(function(){y("load-error");
t.trigger(s?"ra.dialog.close":"ra.iframe.destroy")
});
E();
C("plugin.iframetimedout",{elapsed:new Date().getTime()-p})
},20000);
function A(){if(x){clearTimeout(x);
x=null
}}function u(){return t.data("ra.dialog.buttons")
}function q(H){return t.data("ra.dialog.buttons").getButton(H)
}var k=new e({remote:n.src,container:D,channel:l,props:{width:v,height:F}},{remote:["dialogMessage","setWorkflowConfigurationMessage"],local:{init:function(){if(!r){r=true;
A();
o.addClass("iframe-init");
var H=new Date().getTime()-p;
y("loaded");
E();
t.trigger("ra.iframe.init");
C("plugin.iframeinited",{elapsed:H})
}},resize:m(function(I,H){if(!s){f("iframe",o).css({width:I,height:H})
}}),getLocation:function(){return window.location.href
},getUser:function(){var H=AJS.Meta,I=H?H.get("remote-user-fullname"):null;
if(!I){I=f("a#header-details-user-fullname, .user.ajs-menu-title, a#user").text()
}if(!I){I=f("a#user-menu-link").attr("title")
}return{fullName:I,id:n.uid,key:n.ukey}
},getTimeZone:function(){return n.data.timeZone
},showMessage:function(J,I,H){if(f("#aui-message-bar").length===0){f.html("div").attr("id","aui-message-bar").prependTo("#details-module")
}f(".aui-message#"+J).remove();
AJS.messages.info({title:I,body:"<p>"+f("<div/>").text(H).html()+"<p>",id:J,closeable:false})
},clearMessage:function(H){f(".aui-message#"+H).remove()
},setDialogButtonEnabled:function(I,H){var J=q(I);
if(J){J.setEnabled(H)
}},isDialogButtonEnabled:function(H,J){var I=q(H);
J(I?I.isEnabled():void 0)
},request:function(M,O,L){var K=n.cp+M.url;
function H(Q){var P={headers:{}};
f.each(g,function(S,R){P[R]=Q[R]
});
f.each(a,function(S,R){P.headers[R]=Q.getResponseHeader(R)
});
return P
}function J(P,R,Q){O([P,R,H(Q)])
}function I(Q,R,P){L([H(Q),R,P])
}var N={};
f.each(M.headers||{},function(Q,P){N[Q.toLowerCase()]=P
});
f.ajax({url:K,type:M.type||"GET",data:M.data,dataType:"text",contentType:M.contentType,headers:{Accept:N.accept||"*/*","AP-App-Key":n.key}}).then(J,I)
},getWorkflowConfiguration:function(H,I){I(f("#remoteWorkflowPostFunctionConfiguration-"+H).val())
},saveMacro:function(H){_AP.require("confluence/macro/editor",function(I){I.saveMacro(H)
})
}}});
var t=o.parents(".ap-servlet-placeholder"),z=f("iframe",o);
z.data("ap-rpc",k);
function E(){var H=f(".ap-stats",j);
if(s){var I=t.parent().height();
z.parents(".ap-servlet-placeholder, .ap-container").height(I);
var J=z.parents(".ap-container").height(),K=J-H.outerHeight(true);
z.height(K);
o.height(K)
}H.removeClass("hidden")
}E();
function m(H,J){var I;
return function(){var K=this,M=[].slice.call(arguments);
function L(){I=null;
H.apply(K,M)
}if(I){clearTimeout(I)
}I=setTimeout(L,J||50)
}
}var w=u();
if(w){w.each(function(H,I){I.click(function(J,K){if(r){k.dialogMessage(H,K)
}else{K(true)
}})
})
}var B=false;
f(document).delegate("#add_submit, #update_submit","click",function(H){if(!B){H.preventDefault();
k.setWorkflowConfigurationMessage(function(I){if(I.valid){f("#remoteWorkflowPostFunctionConfiguration-"+I.uuid).val(I.value);
B=true;
f(H.target).click()
}})
}});
t.bind("ra.iframe.destroy",function(){k.destroy()
});
t.trigger("ra.iframe.create")
}return function(j){function i(){d(j.ns).find("iframe").each(function(k,l){var m=f(l).data("ap-rpc");
if(m){m.destroy()
}});
b(j)
}if(f.isReady){h(i)
}else{i()
}}
});
if(!_AP.create){_AP.require(["host/main"],function(a){_AP.create=a
})
};

==> remotable-plugins-plugin-0.9.1137.jar: js/iframe-min/host/main-min.js <==
_AP.define("host/main",["_xdm-rpc"],function(e){var f=AJS.$,g=["status","statusText","responseText"],a=["Content-Type"],c=(AJS.EventQueue=AJS.EventQueue||[]),h=window.requestAnimationFrame||function(i){setTimeout(i,10)
};
function d(i){return f("#embedded-"+i)
}function b(n){var G=n.ns,i="ap-"+G,j=f("#"+i),o=d(G),D=o.attr("id"),l="channel-"+G,v=n.w||"100%",F=n.h||"0",p=new Date().getTime(),s=!!n.dlg,r;
function C(H,I){I=f.extend(I||{},{moduleKey:G});
c.push({name:H,properties:I})
}function y(H){j.find(".ap-status").addClass("hidden");
j.find(".ap-"+H).removeClass("hidden")
}var x=setTimeout(function(){x=null;
y("load-timeout");
var H=j.find(".ap-load-timeout");
H.find("a.ap-btn-cancel").click(function(){y("load-error");
t.trigger(s?"ra.dialog.close":"ra.iframe.destroy")
});
E();
C("plugin.iframetimedout",{elapsed:new Date().getTime()-p})
},20000);
function A(){if(x){clearTimeout(x);
x=null
}}function u(){return t.data("ra.dialog.buttons")
}function q(H){return t.data("ra.dialog.buttons").getButton(H)
}var k=new e({remote:n.src,container:D,channel:l,props:{width:v,height:F}},{remote:["dialogMessage","setWorkflowConfigurationMessage"],local:{init:function(){if(!r){r=true;
A();
o.addClass("iframe-init");
var H=new Date().getTime()-p;
y("loaded");
E();
t.trigger("ra.iframe.init");
C("plugin.iframeinited",{elapsed:H})
}},resize:m(function(I,H){if(!s){f("iframe",o).css({width:I,height:H})
}}),fireEvent:function(I,H){C("p3.iframe."+I,H)
},getLocation:function(){return window.location.href
},getUser:function(){var H=AJS.Meta,I=H?H.get("remote-user-fullname"):null;
if(!I){I=f("a#header-details-user-fullname, .user.ajs-menu-title, a#user").text()
}if(!I){I=f("a#user-menu-link").attr("title")
}return{fullName:I,id:n.uid}
},getTimeZone:function(){return n.data.timeZone
},showMessage:function(J,I,H){if(f("#aui-message-bar").length===0){f.html("div").attr("id","aui-message-bar").prependTo("#details-module")
}f(".aui-message#"+J).remove();
AJS.messages.info({title:I,body:"<p>"+f("<div/>").text(H).html()+"<p>",id:J,closeable:false})
},clearMessage:function(H){f(".aui-message#"+H).remove()
},setDialogButtonEnabled:function(I,H){var J=q(I);
if(J){J.setEnabled(H)
}},isDialogButtonEnabled:function(H,J){var I=q(H);
J(I?I.isEnabled():void 0)
},request:function(M,N,L){var K=n.cp+M.url;
function H(P){var O={headers:{}};
f.each(g,function(R,Q){O[Q]=P[Q]
});
f.each(a,function(R,Q){O.headers[Q]=P.getResponseHeader(Q)
});
return O
}function J(O,Q,P){N([O,Q,H(P)])
}function I(P,Q,O){L([H(P),Q,O])
}f.ajax({url:K,type:M.type||"GET",data:M.data,dataType:"text",contentType:M.contentType,headers:{Accept:"*/*","AP-App-Key":n.key}}).then(J,I)
},getWorkflowConfiguration:function(H,I){I(f("#remoteWorkflowPostFunctionConfiguration-"+H).val())
},saveMacro:function(H){_AP.require("confluence/macro/editor",function(I){I.saveMacro(H)
})
}}});
var t=o.parents(".ap-servlet-placeholder"),z=f("iframe",o);
z.data("ap-rpc",k);
function E(){var H=f(".ap-stats",j);
if(s){var I=t.parent().height();
z.parents(".ap-servlet-placeholder, .ap-container").height(I);
var J=z.parents(".ap-container").height(),K=J-H.outerHeight(true);
z.height(K);
o.height(K)
}H.removeClass("hidden")
}E();
function m(H,J){var I;
return function(){var K=this,M=[].slice.call(arguments);
function L(){I=null;
H.apply(K,M)
}if(I){clearTimeout(I)
}I=setTimeout(L,J||50)
}
}var w=u();
if(w){w.each(function(H,I){I.click(function(J,K){if(r){k.dialogMessage(H,K)
}else{K(true)
}})
})
}var B=false;
f(document).delegate("#add_submit, #update_submit","click",function(H){if(!B){H.preventDefault();
k.setWorkflowConfigurationMessage(function(I){if(I.valid){f("#remoteWorkflowPostFunctionConfiguration-"+I.uuid).val(I.value);
B=true;
f(H.target).click()
}})
}});
t.bind("ra.iframe.destroy",function(){k.destroy()
});
t.trigger("ra.iframe.create")
}return function(j){function i(){d(j.ns).find("iframe").each(function(k,l){var m=f(l).data("ap-rpc");
if(m){m.destroy()
}});
b(j)
}if(f.isReady){h(i)
}else{i()
}}
});
if(!_AP.create){_AP.require(["host/main"],function(a){_AP.create=a
})
};
